@@ -5,16 +5,16 @@ import docker
 import yaml
 
 from sys import argv
+from textwrap import indent
 from os.path import normpath
 
 from .utils import rgetattr, rsetattr
 
 
 class Deployment:
-    def __init__(self, path="", verbose=False):
+    def __init__(self, path=""):
         # Initialize paths and log settings
         self.path = path
-        self.verbose = verbose
 
         # Load the clients and config
         with open(normpath(path)) as config:
@@ -90,12 +90,14 @@ class Deployment:
 
             resource_name, action_name = node_name.split(".")
 
+            print(node_name)
+
             try:
                 action = rgetattr(node_client, action_name)
                 value = action(**self.shared_lookup(node_args))
 
-                if self.verbose:
-                    print(f"setting value {value} for {node_name}")
+                print(
+                    indent(f"setting value {value}", '\t+ ', lambda _: True))
 
                 rsetattr(
                     context=self.config,
@@ -103,7 +105,8 @@ class Deployment:
                     value=value,
                 )
             except Exception as e:
-                print("err: ", e)
+                print(
+                    indent(f"err: {e}", '\t- ', lambda _: True))
 
 
 def main():
